
# This file was generated by 'versioneer.py' (0.19) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2022-10-18T21:57:12+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "a19580efb174c5347635eff9105d982bd1a5e7d2",
 "version": "1.0.4"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
